==> mongo-cxx-driver-r3.9.0.tar.gz: mongo-cxx-driver-r3.9.0/src/mongocxx/lib/mongocxx/v_noabi/mongocxx/events/command_succeeded_event.cpp <==
// Copyright 2018-present MongoDB Inc.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

#include <bsoncxx/private/helpers.hh>
#include <bsoncxx/stdx/make_unique.hpp>
#include <mongocxx/events/command_succeeded_event.hpp>
#include <mongocxx/private/libmongoc.hh>

#include <mongocxx/config/private/prelude.hh>

namespace mongocxx {
inline namespace v_noabi {
namespace events {

command_succeeded_event::command_succeeded_event(const void* event) : _succeeded_event(event) {}

command_succeeded_event::~command_succeeded_event() = default;

bsoncxx::document::view command_succeeded_event::reply() const {
    auto reply = libmongoc::apm_command_succeeded_get_reply(
        static_cast<const mongoc_apm_command_succeeded_t*>(_succeeded_event));
    return {bson_get_data(reply), reply->len};
}

bsoncxx::stdx::string_view command_succeeded_event::command_name() const {
    return libmongoc::apm_command_succeeded_get_command_name(
        static_cast<const mongoc_apm_command_succeeded_t*>(_succeeded_event));
}

std::int64_t command_succeeded_event::duration() const {
    return libmongoc::apm_command_succeeded_get_duration(
        static_cast<const mongoc_apm_command_succeeded_t*>(_succeeded_event));
}

std::int64_t command_succeeded_event::request_id() const {
    return libmongoc::apm_command_succeeded_get_request_id(
        static_cast<const mongoc_apm_command_succeeded_t*>(_succeeded_event));
}

std::int64_t command_succeeded_event::operation_id() const {
    return libmongoc::apm_command_succeeded_get_operation_id(
        static_cast<const mongoc_apm_command_succeeded_t*>(_succeeded_event));
}

bsoncxx::stdx::optional<bsoncxx::oid> command_succeeded_event::service_id() const {
    const bson_oid_t* bson_oid = libmongoc::apm_command_succeeded_get_service_id(
        static_cast<const mongoc_apm_command_succeeded_t*>(_succeeded_event));

    if (nullptr == bson_oid)
        return {bsoncxx::stdx::nullopt};

    return {bsoncxx::helpers::make_oid(bson_oid)};
}

bsoncxx::stdx::string_view command_succeeded_event::host() const {
    return libmongoc::apm_command_succeeded_get_host(
               static_cast<const mongoc_apm_command_succeeded_t*>(_succeeded_event))
        ->host;
}

std::uint16_t command_succeeded_event::port() const {
    return libmongoc::apm_command_succeeded_get_host(
               static_cast<const mongoc_apm_command_succeeded_t*>(_succeeded_event))
        ->port;
}

}  // namespace events
}  // namespace v_noabi
}  // namespace mongocxx

==> mongo-cxx-driver-r3.10.2.tar.gz: mongo-cxx-driver-r3.10.2/src/mongocxx/lib/mongocxx/v_noabi/mongocxx/events/command_succeeded_event.cpp <==
// Copyright 2018-present MongoDB Inc.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

#include <bsoncxx/private/helpers.hh>
#include <bsoncxx/stdx/make_unique.hpp>
#include <mongocxx/events/command_succeeded_event.hpp>
#include <mongocxx/private/libmongoc.hh>

#include <mongocxx/config/private/prelude.hh>

namespace mongocxx {
namespace v_noabi {
namespace events {

command_succeeded_event::command_succeeded_event(const void* event) : _succeeded_event(event) {}

command_succeeded_event::~command_succeeded_event() = default;

bsoncxx::v_noabi::document::view command_succeeded_event::reply() const {
    auto reply = libmongoc::apm_command_succeeded_get_reply(
        static_cast<const mongoc_apm_command_succeeded_t*>(_succeeded_event));
    return {bson_get_data(reply), reply->len};
}

bsoncxx::v_noabi::stdx::string_view command_succeeded_event::command_name() const {
    return libmongoc::apm_command_succeeded_get_command_name(
        static_cast<const mongoc_apm_command_succeeded_t*>(_succeeded_event));
}

std::int64_t command_succeeded_event::duration() const {
    return libmongoc::apm_command_succeeded_get_duration(
        static_cast<const mongoc_apm_command_succeeded_t*>(_succeeded_event));
}

std::int64_t command_succeeded_event::request_id() const {
    return libmongoc::apm_command_succeeded_get_request_id(
        static_cast<const mongoc_apm_command_succeeded_t*>(_succeeded_event));
}

std::int64_t command_succeeded_event::operation_id() const {
    return libmongoc::apm_command_succeeded_get_operation_id(
        static_cast<const mongoc_apm_command_succeeded_t*>(_succeeded_event));
}

bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::oid> command_succeeded_event::service_id()
    const {
    const bson_oid_t* bson_oid = libmongoc::apm_command_succeeded_get_service_id(
        static_cast<const mongoc_apm_command_succeeded_t*>(_succeeded_event));

    if (nullptr == bson_oid)
        return {bsoncxx::v_noabi::stdx::nullopt};

    return {bsoncxx::helpers::make_oid(bson_oid)};
}

bsoncxx::v_noabi::stdx::string_view command_succeeded_event::host() const {
    return libmongoc::apm_command_succeeded_get_host(
               static_cast<const mongoc_apm_command_succeeded_t*>(_succeeded_event))
        ->host;
}

std::uint16_t command_succeeded_event::port() const {
    return libmongoc::apm_command_succeeded_get_host(
               static_cast<const mongoc_apm_command_succeeded_t*>(_succeeded_event))
        ->port;
}

}  // namespace events
}  // namespace v_noabi
}  // namespace mongocxx
